% Final Design Simulation

clc; close all; clear;

% Dimensions
D0 = 0.03175; D1 = 0.0254; D2 = 0.0508; D3 = D1 - (D1*0.25); % meters
N = 3/40; % meters / length unit
e = 0.15 / 10^3;  % meters

L0 = 13*N; L3 = 30*N; L4 = 5*N; L5 = 3*N; L6 = 3*N; L7 = 5*N; L8 = 18*N; % meters
L9 = 5*N; L10 = 18*N; L11 = 10*N; L12 = 4*N; L13 = 9*N; L14 = 4*N; % meters
L15 = 3*N; L16 = N; L17 = 17*N; L18 = 3*N; L20 = 5*N; L19 = 5*N; % meters

% Pump Specs
Q = linspace(0, 100, 100); %gpm
pHead = 0; % ft
Q = 0.0000631 .* Q; % meters ^ 3/ s
pHead = 0.3048 * pHead; % meters

% Fluid Properties T = 25 C
P0 = 0; % P atm and gage
Density = 997; % kilogram / meters ^ 3
kinViscosity = 8.96E-7; % meters ^ 2 / seconds

% Additional constants
Gravity = 9.81; % meters / seconds ^ 2

% Head loss Coefficients
K90 = 0.3; Ktee = 1; Kex = 0.6; Kcon = 0.4; Kfm = 7; Kval = 0.5; Kre = 0.5;
KteeS = 0.3; Kpitot = 7;

% Initialize storage vars
Pressures = zeros(3, 32);
hLoss = zeros(3, 14);
Re = zeros(1, 3);
f = zeros(1, 3);
totalHead = zeros(3, length(Q));

for n = 1:1:length(Q)
    % Determine pressure across system
    Re0 = 4 * Q(n) / (pi * D0 * kinViscosity);
    f0 = 0.25*(log10(e/(D0*3.7)+(5.74/(Re0^0.9))))^(-2);
    Re(1) = 4 * Q(n) / (pi * D1 * kinViscosity);
    f(1) = 0.25*(log10(e/(D1*3.7)+(5.74/(Re(1)^0.9))))^(-2);

    HM = (8*(Q(n)^2)/(Gravity*pi^2))*((f0*L0/D0));
    Hm = (8*(Q(n)^2)/(Gravity*pi^2))*((1/D0^4)*(Kre)+(1/D1^4)*(K90 + Kfm));
    deltaZ = 9*N;

    % Segment 1 Simulation 
    % Pump Segment
    Pressures(1, 1) = P0 + Density*Gravity*(pHead - (HM + Hm) - deltaZ - (8*Q(n)^2)/((pi^2)*Gravity*(D1^4)));
    Pressures(1, 2) = Pressures(1, 1) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*((f(1)*L3)/(D1)));
    hLoss(1,1) = Pressures(1, 1) - Pressures(1, 2);
    Pressures(1, 3) = Pressures(1, 2) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(K90));
    hLoss(1,2) = Pressures(1, 2) - Pressures(1, 3);
    Pressures(1, 4) = Pressures(1, 3) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(f(1)*L4)/D1);
    hLoss(1,3) = Pressures(1, 3) - Pressures(1, 4);
    % Segment 1
    Pressures(1, 5) = Pressures(1, 4) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(Ktee));
    hLoss(1,4) = Pressures(1, 4) - Pressures(1, 5);
    Pressures(1, 6) = Pressures(1, 5) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(f(1)*L7)/D1);
    hLoss(1,5) = Pressures(1, 5) - Pressures(1, 6);
    Pressures(1, 7) = Pressures(1, 6) + ((8*(Q(n)^2)*Density)/(pi^2))*((D1^4-D2^4)) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(Kex)) ;
    hLoss(1,6) = Pressures(1, 6) - Pressures(1, 7);
    Re(2) = 4 * Q(n) / (pi * D2 * kinViscosity);
    f(2) = 0.25*(log10(e/(D2*3.7)+(5.74/(Re(2)^0.9))))^(-2);
    Pressures(1, 8) = Pressures(1, 7) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D2^4)))*(f(2)*L8)/D2);
    hLoss(1,7) = Pressures(1, 7) - Pressures(1, 8);
    Pressures(1, 30) = Pressures(1, 8) + ((8*(Q(n)^2)*Density)/(pi^2))*((D2^4-D1^4)) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(Kcon)) ;
    hLoss(1,8) = Pressures(1, 8) - Pressures(1, 30);
    Pressures(1, 9) = Pressures(1, 30) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(f(1)*L19)/D1);
    hLoss(1,9) = Pressures(1, 30) - Pressures(1, 9);
    Pressures(1, 29) = Pressures(1, 9) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(K90));
    hLoss(1,10) = Pressures(1, 9) - Pressures(1, 29);
    Pressures(1, 27) = Pressures(1, 29) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(f(1)*L14)/D1);
    hLoss(1,11) = Pressures(1, 29) - Pressures(1, 27);
    Pressures(1, 28) = Pressures(1, 27) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(KteeS));
    hLoss(1,12) = Pressures(1, 27) - Pressures(1, 28);
    Pressures(1, 25) = Pressures(1, 28) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*((f(1)*L15)/D1));
    hLoss(1,13) = Pressures(1, 27) - Pressures(1, 25);
    Pressures(1, 26) = Pressures(1, 25) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(Ktee));
    hLoss(1,14) = Pressures(1, 25) - Pressures(1, 26);
    % Return Segment
    Pressures(1, 32) = Pressures(1, 26) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*((f(1)*L17/D1) + 3*K90) - deltaZ);

    % Segment 2 Simulation
    % Pump Segment
    Pressures(2, 1) = P0 + Density*Gravity*(pHead - (HM + Hm) - deltaZ - (8*Q(n)^2)/((pi^2)*Gravity*(D1^4)));
    Pressures(2, 2) = Pressures(2, 1) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*((f(1)*L3)/(D1)));
    hLoss(2,1) = Pressures(2, 1) - Pressures(2, 2);
    Pressures(2, 3) = Pressures(2, 2) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(K90));
    hLoss(2,2) = Pressures(2, 2) - Pressures(2, 3);
    Pressures(2, 4) = Pressures(2, 3) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(f(1)*L4)/D1);
    hLoss(2,3) = Pressures(2, 3) - Pressures(2, 4);
    % Segment 2
    Pressures(2, 10) = Pressures(2, 4) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(KteeS));
    hLoss(2,4) = Pressures(2, 4) - Pressures(2, 10);
    Pressures(2, 11) = Pressures(2, 10) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(f(1)*L5)/D1);
    hLoss(2,5) = Pressures(2, 10) - Pressures(2, 11);
    Pressures(2, 12) = Pressures(2, 11) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(Ktee));
    hLoss(2,6) = Pressures(2, 11) - Pressures(2, 12);
    Pressures(2, 13) = Pressures(2, 12) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(f(1)*L9)/D1);
    hLoss(2,7) = Pressures(2, 12) - Pressures(2, 13);
    Pressures(2, 14) = Pressures(2, 13) + ((8*(Q(n)^2)*Density)/(pi^2))*(((1/(D1^4))-(1/(D3^4)))) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D3^4)))*(Kcon)) ;
    hLoss(2,8) = Pressures(2, 13) - Pressures(2, 14);
    Re(3) = 4 * Q(n) / (pi * D3 * kinViscosity);
    f(3) = 0.25*(log10(e/(D3*3.7)+(5.74/(Re(3)^0.9))))^(-2);
    Pressures(2, 15) = Pressures(2, 14) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D3^4)))*(f(3)*L10)/D3);
    hLoss(2,9) = Pressures(2, 14) - Pressures(2, 15);
    Pressures(2, 31) = Pressures(2, 15) + ((8*(Q(n)^2)*Density)/(pi^2))*(((1/(D3^4))-(1/(D1^4)))) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D3^4)))*(Kex)) ;
    hLoss(2,10) = Pressures(2, 15) - Pressures(2, 31);
    Pressures(2, 16) = Pressures(2, 31) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(f(1)*L20)/D1);
    hLoss(2,11) = Pressures(2, 31) - Pressures(2, 16);
    Pressures(2, 28) = Pressures(2, 16) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(Ktee));
    hLoss(2,12) = Pressures(2, 16) - Pressures(2, 28);
    Pressures(2, 25) = Pressures(2, 28) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*((f(1)*L15)/D1));
    hLoss(2,13) = Pressures(2, 28) - Pressures(2, 25);
    Pressures(2, 26) = Pressures(2, 25) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(Ktee));
    hLoss(2,14) = Pressures(2, 25) - Pressures(2, 26);
    % Return Segment
    Pressures(2, 32) = Pressures(2, 26) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*((f(1)*L17/D1) + 3*K90) - deltaZ);

    % Segment 3 Simulation
    % Pump Segment
    Pressures(3, 1) = P0 + Density*Gravity*(pHead - (HM + Hm) - deltaZ - (8*Q(n)^2)/((pi^2)*Gravity*(D1^4)));
    Pressures(3, 2) = Pressures(3, 1) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*((f(1)*L3)/(D1)));
    hLoss(3,1) = Pressures(3, 1) - Pressures(3, 2);
    Pressures(3, 3) = Pressures(3, 2) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(K90));
    hLoss(3,2) = Pressures(3, 2) - Pressures(3, 3);
    Pressures(3, 4) = Pressures(3, 3) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(f(1)*L4)/D1);
    hLoss(3,3) = Pressures(3, 3) - Pressures(3, 4);
    % Segment 2
    Pressures(3, 10) = Pressures(3, 4) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(KteeS));
    hLoss(3,4) = Pressures(3, 4) - Pressures(3, 10);
    Pressures(3, 11) = Pressures(3, 10) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(f(1)*L5)/D1);
    hLoss(3,5) = Pressures(3, 10) - Pressures(3, 11);
    Pressures(3, 17) = Pressures(3, 11) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(KteeS));
    hLoss(3,6) = Pressures(3, 11) - Pressures(3, 17);
    Pressures(3, 18) = Pressures(3, 17) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(f(1)*L6)/D1);
    hLoss(3,7) = Pressures(3, 17) - Pressures(3, 18);
    Pressures(3, 19) = Pressures(3, 18) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(K90)) ;
    hLoss(3,8) = Pressures(3, 18) - Pressures(3, 19);
    Pressures(3, 20) = Pressures(3, 19) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(f(1)*L11)/D1);
    hLoss(3,9) = Pressures(3, 19) - Pressures(3, 20);
    Pressures(3, 21) = Pressures(3, 20) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(Kpitot));
    hLoss(3,10) = Pressures(3, 20) - Pressures(3, 21);
    Pressures(3, 22) = Pressures(3, 21) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(f(1)*L12)/D1);
    hLoss(3,11) = Pressures(3, 21) - Pressures(3, 22);
    Pressures(3, 23) = Pressures(3, 22) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(Kval));
    hLoss(3,12) = Pressures(3, 22) - Pressures(3, 23);
    Pressures(3, 24) = Pressures(3, 23) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(f(1)*L13)/D1);
    hLoss(3,13) = Pressures(3, 23) - Pressures(3, 24);
    Pressures(3, 26) = Pressures(3, 24) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*(KteeS));
    hLoss(3,14) = Pressures(3, 24) - Pressures(3, 26);
    % Return Segment
    Pressures(3, 32) = Pressures(3, 26) - Density*Gravity*(((8*Q(n)^2)/((pi^2)*Gravity*(D1^4)))*((f(1)*L17/D1) + 3*K90) - deltaZ);
    
    totalHead(1, n) = sum(hLoss(1, :)) * 3.28 / (Density * Gravity);
    totalHead(2, n) = sum(hLoss(2, :)) * 3.28 / (Density * Gravity);
    totalHead(3, n) = sum(hLoss(3, :)) * 3.28 / (Density * Gravity);
    
end

hold on
Q = Q ./ (0.0000631);
pumpCurve = -0.0223.*Q.^2 + 0.1147.*Q + 141.77;
pumpCurve(pumpCurve<0) = nan;
plot(Q, pumpCurve, '--')
plot((Q ), totalHead)
title('Pump Vs System Head')
xlabel('Flow Rate (gpm)')
ylabel('Head (ft)')
legend('Pump', 'Segment 1', 'Segment 2', 'Segment 3', 'Location','best')
grid on
ylim([0 150])
xlim([0 70])
yticks(0:10:150)

Pump_Vs_System;
text(Qs(1,1) + 3, HLossesEqual(1,1), sprintf('Q: %0.2f (gpm)\nH: %0.2f (ft)\nRe1: %0.2d\nRe2: %0.2d', Qs(1,1), HLossesEqual(1,1), Qs(1,1)* 4 * 0.0000631 / (kinViscosity*pi*D1), Qs(1,1)* 4 * 0.0000631 / (kinViscosity*pi*D2)));
text(Qs(2,1) - 2, HLossesEqual(2,1) - 3, sprintf('Q: %0.2f (gpm)\nH: %0.2f (ft)\nRe1: %0.2d\nRe2: %0.2d', Qs(2,1), HLossesEqual(2,1), Qs(2,1)* 4 * 0.0000631 / (kinViscosity*pi*D1), Qs(2,1)* 4 * 0.0000631 / (kinViscosity*pi*D3)), 'HorizontalAlignment','right');
text(Qs(3,1) + 2, HLossesEqual(3,1) + 3, sprintf('Q: %0.2f (gpm)\nH: %0.2f (ft)\nRe: %0.2d', Qs(3,1), HLossesEqual(3,1), Qs(3,1)* 4 * 0.0000631 / (kinViscosity*pi*D1)));


